@@ -214,10 +214,24 @@ class EvaluationStore:
             entity_targets=other.entity_targets,
         )
 
-    def has_prediction_target_mismatch(self) -> bool:
+    def _check_entity_prediction_target_mismatch(self) -> bool:
+        """Checks that same entities were expected and actually extracted.
+
+        Possible duplicates or differences in order should not matter.
+        """
+        deduplicated_targets = set(
+            tuple(entity.items()) for entity in self.entity_targets
+        )
+        deduplicated_predictions = set(
+            tuple(entity.items()) for entity in self.entity_predictions
+        )
+        return deduplicated_targets != deduplicated_predictions
+
+    def check_prediction_target_mismatch(self) -> bool:
+        """Checks if intent, entity or action predictions don't match expected ones."""
         return (
             self.intent_predictions != self.intent_targets
-            or self.entity_predictions != self.entity_targets
+            or self._check_entity_prediction_target_mismatch()
             or self.action_predictions != self.action_targets
         )
 
@@ -538,14 +552,14 @@ def _collect_user_uttered_predictions(
             entity_predictions=_clean_entity_results(event.text, predicted_entities),
         )
 
-    if user_uttered_eval_store.has_prediction_target_mismatch():
+    if user_uttered_eval_store.check_prediction_target_mismatch():
         partial_tracker.update(
             WronglyClassifiedUserUtterance(event, user_uttered_eval_store)
         )
         if fail_on_prediction_errors:
             story_dump = YAMLStoryWriter().dumps(partial_tracker.as_story().story_steps)
             raise WrongPredictionException(
-                f"NLU model predicted a wrong intent. Failed Story:"
+                f"NLU model predicted a wrong intent or entities. Failed Story:"
                 f" \n\n{story_dump}"
             )
     else:
@@ -679,7 +693,7 @@ def _collect_action_executed_predictions(
         action_predictions=[predicted_action], action_targets=[expected_action]
     )
 
-    if action_executed_eval_store.has_prediction_target_mismatch():
+    if action_executed_eval_store.check_prediction_target_mismatch():
         partial_tracker.update(
             WronglyPredictedAction(
                 expected_action_name,
@@ -923,7 +937,7 @@ async def _collect_story_predictions(
 
         action_list.extend(tracker_actions)
 
-        if tracker_results.has_prediction_target_mismatch():
+        if tracker_results.check_prediction_target_mismatch():
             # there is at least one wrong prediction
             failed_stories.append(predicted_tracker)
             correct_dialogues.append(0)
