@@ -5,10 +5,6 @@ from typing import Any, Dict, List, Text, Union
 
 from rasa.shared.nlu.constants import TEXT
 from rasa.shared.nlu.training_data.formats import MarkdownWriter, MarkdownReader
-from rasa.shared.nlu.training_data.formats.readerwriter import (
-    TrainingDataReader,
-    TrainingDataWriter,
-)
 from rasa.shared.nlu.training_data.training_data import TrainingData
 import rasa.shared.utils.io as io_utils
 
